
## ChangeLog

### 0.3.3 (2015-03-21)

* added PDF conversion sample script
* updated README as tutorial

### 0.3.2 (2014-06-07)

* added some classes for calc
* changed data directory option of command line argument (-d, --datadirs) to be able to store multiple directories

### 0.3.1 (2014-05-07)

* added command line argument (-f, --file) to be able to read OpenDocument file

### 0.3.0 (2014-05-05)

* first release
